@@ -1,6 +1,6 @@
 import sys
 
 
-def output(x, y, text):
+def output(y, x, text):
 	sys.stdout.write("\x1b7\x1b[%d;%df%s\x1b8" % (x, y, text))
 	sys.stdout.flush()
